︠163a4016-b71d-4bc7-a2ee-6141c1463401︠
Author: Vincent J. Matsko
Date: 17 April 2016, Day036
Post: Fractals VII:  Iterated Function Systems, III
︡00c4a58f-607c-426e-8d9c-af09f3bb62dd︡
︠cdbe8b52-af14-48fe-bb00-8b3a079740fbs︠
# This is the basic algorithm.
# You can adapt it many ways.  Feel free to experiment!

# n is the number of points to plot
def sierpinski(n):
    # These variables keep track of the differently colored points.
    # For more transformations, add more variables.
    ptscolor1 = []
    ptscolor2 = []
    ptscolor3 = []
    # Begin at (0,0).  You may begin anywhere you like.
    last = (0,0)
    for i in range(n):
        select = random()
        (x,y) = last
        if 0 <= select < 0.333:        # 1/3 chance for 1st transformation.
            last = (0.5*x,0.5*y)       # Note how the affine transformation is represented.
            ptscolor1.append(last)
        elif 0.333 <= select < 0.667:  # 1/3 chance for 2nd transformation.
            last = (0.5*x + 0.5,0.5*y)
            ptscolor2.append(last)
        else:                          # remaining 1/3 chance for last transformation.
            last = (0.5*x,0.5*y + 0.5)
            ptscolor3.append(last)
    # You may use any colors you wish!
    # The "aspect_ratio=1" keeps the axes at the same scale.
    show(points(ptscolor1, color='red') + points(ptscolor2, color='blue') + points(ptscolor3, color='orange'), aspect_ratio=1)
︡bac556c8-4666-4dc4-a15a-a2cb0993d243︡︡{"done":true}
︠6ac64177-9252-4d4d-a306-fdaadd4affeas︠
sierpinski(1000)
︡f4e4921e-d794-4484-9bc9-06f5b44f5323︡︡{"file":{"filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/27074/tmp_rxVB9p.svg","show":true,"text":null,"uuid":"be05c416-a2b5-456a-a02c-e1720595ee1e"},"once":false}︡{"html":"<div align='center'></div>"}︡{"done":true}
︠c9856106-ce82-42f9-9a7b-89e8b0adfeeb︠
# The same algorithm works even if you do not use affine transformations.
# The possibilites are virtually endless!

# n is the number of points to plot
def nonaffine(n):
    # These variables keep track of the differnetly colored points.
    # For more transformations, add more variables.
    ptscolor1 = []
    ptscolor2 = []
    ptscolor3 = []
    # Begin at (0,0).  You may begin anywhere you like.
    last = (0,0)
    for i in range(n):
        select = random()
        (x,y) = last
        if 0 <= select < 0.5:                  # 1/3 chance for 1st transformation.
            last = (x**2,0.75*y)               # No longer affine!
            ptscolor1.append(last)
        elif 0.5 <= select < 0.8:              # 1/3 chance for 2nd transformation.
            last = (-0.5*x + 0.5,-y**2)        # No longer affine!
            ptscolor2.append(last)
        else:                                  # remaining 1/3 chance for last transformation.
            last = (0.5*x,-0.75*(y**2) + 0.5)  # No longer affine!
            ptscolor3.append(last)
    # You may use any colors you wish!
    # The "size=3" made the red points smaller.  You may adjust this parameter.
    # The "aspect_ratio=1" keeps the axes at the same scale.
    show(points(ptscolor1, size=3, color='red') + points(ptscolor2, color='blue') + points(ptscolor3, color='orange'), aspect_ratio=1)
︡c3a74a8f-509c-4752-ad3a-a02d83d782ec︡︡{"done":true}
︠c5693a19-0c2a-49ed-9703-0cbaef96b64es︠
nonaffine(3000)
︡e70a883c-e7f4-438f-9ae6-a5444fd28d5f︡︡{"file":{"filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/27074/tmp_bnZ7RX.svg","show":true,"text":null,"uuid":"adfa09fc-55f1-4626-87ff-9ef357393dc2"},"once":false}︡{"html":"<div align='center'></div>"}︡{"done":true}
︠6e173096-0cbd-4bc0-8499-183dc965b8a0s︠
# For the adventurous, you can create 3D fractals as well!
# The algorithm is the same, except the affine transformations are three-dimensional. 
def sierpinski3d(n):
    ptsclr1 = []
    ptsclr2 = []
    ptsclr3 = []
    ptsclr4 = []
    last = (0,0,0)
    for i in range(n):
        select = random()
        (x,y,z) = last
        if 0 <= select < 0.25:
            last = (0.5*x,0.5*y,0.5*z)
            ptsclr1.append(last)
        elif 0.25 <= select < 0.5:
            last = (0.5*x + 0.5,0.5*y,0.5*z)
            ptsclr2.append(last)
        elif 0.5 <= select < 0.75:
            last = (0.5*x,0.5*y + 0.5,0.5*z)
            ptsclr3.append(last)
        else:
            last = (0.5*x,0.5*y,0.5*z + 0.5)
            ptsclr4.append(last)
    P=point3d(ptsclr1, size=2, color='red') + point3d(ptsclr2, size=2, color='blue') + point3d(ptsclr3, size=2, color='orange') + point3d(ptsclr4, size=2, color='purple',viewpoint=(1,1,1))
    show(P)
︡c741639f-19c1-4d2c-860b-ec0c5db9b89c︡︡{"done":true}
︠59058b6d-5a43-447b-aba5-613f66c040dds︠
sierpinski3d(3000)
︡e8a0f0d7-3c4f-4c3d-8cfc-e1109442bfe7︡︡{"file":{"filename":"bdbeed92-a582-4100-9d64-0a7be8d69260.sage3d","uuid":"bdbeed92-a582-4100-9d64-0a7be8d69260"}}︡{"html":"<div align='center'></div>"}︡{"done":true}
︠9c4d785e-fce3-477c-b188-73eaf1355090︠










